import Taro, { Component } from '@tarojs/taro'
import { View, Button, Text, Image, Input } from '@tarojs/components'
import { AtIcon, AtModal, AtModalHeader, AtModalContent, AtModalAction, AtNoticebar } from 'taro-ui'

import VoucherPosterComponent from './voucherPosterComponent/voucherPosterComponent'

import onClickValueService from '../../util/onClickValueService'
import './filteredShopComponent.scss'
import URL from '../../serviceAPI.config'
import { getGlobalStorage } from '../../util/getSetStoage';

const hornIcon = require('../../icons/horn.png')
const houseIcon = require('../../icons/house.png')

class recommondShop extends Component {

    static defaultProps = {
        shop: {
            shop_name: 'kobe',
            goods: [{ goods_url: 'www.kobe.com', goods_price: '999', goods_name: 'kobe' }],
            shop_address: 'kobe road',
            distance: '247km',
            ads: 'Have you ever seen Los Angels sun dawn in 4 AM in the morning?',
            left_nums: '999'
        }
    }

    config = {
        navigationBarTitleText: 'recommondShop'
    }
    constructor() {
        super(...arguments);
        this.state = {
            isOpenVoucher: false,
            isOpenConsult: false,
            consultTip: '',
            voucherResponseMsg: 'i am voucherResponseMsg',
            userName: '',
            userPhone: '',
            isCanConsult: true,
            isCanVoucher: true

        }
    }
    goToShop(e) {

        const value = onClickValueService(e)
        Taro.navigateTo({
            url: '/pages/shop/shop?id=' + value.shop_id
        })
    }
    // api 优惠券请求  
    getVoucherInfo({ user = this.state.userName,
        phone = this.state.userPhone,
        shops = [this.props.shop.shop_id],
        source_type = 4,
        flag = false,
        source_level = this.props.categoryLevel }) {
        Taro.request({
            url: URL.GetVoucherInfo,
            method: 'POST',
            dataType: 'json',
            data: {
                data: JSON.stringify({
                    user: user,
                    phone: phone,
                    shops: shops,
                    source_type: source_type,
                    flag: flag,
                    source_level: source_level
                })
            },


            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'X-Requested-With': 'XMLHttpRequest',
                'Cookie': 'PFWSSS=' + getGlobalStorage('session_id'),
            }
        })
            .then(res => {
                this.setState({
                    voucherResponseMsg: res.data.tips,
                    isCanVoucher: res.data.canConsult,
                })
                console.log('优惠券请求', res)
            })

    }
    // api 咨询信息 

    getConsultInfo({
        user = this.state.userName,
        phone = this.state.userPhone,
        shops = [this.props.shop.shop_id],
        source_type = "2",
        flag = false,
        source_level = this.props.categoryLevel,
    }) {
        Taro.request({
            url: URL.GetConsultInfo,
            method: 'POST',
            dataType: 'json',
            data: {
                data: JSON.stringify({
                    user: user,
                    phone: phone,
                    shops: shops,
                    source_type: source_type,
                    flag: flag,
                    source_level: source_level,
                })
            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'X-Requested-With': 'XMLHttpRequest',
                'Cookie': 'PFWSSS=' + getGlobalStorage('session_id'),
            }
        })
            .then(res => {
                this.setState({ consultTip: res.data.tips, isCanConsult: res.data.canConsult })
                console.log('咨询请求', res)
            })
    }
    // api 购买咨询 BuyConsult
    buyConsult({ user = this.state.userName,
        phone = this.state.userPhone,
        shops = [this.props.shop.shop_id],
        source_type = "2",
        source_level = this.props.categoryLevel,
        source_class = this.props.classId === '-1' ? '' : this.props.classId,
        coupons_flag = 0 }) {
        Taro.request({
            url: URL.BuyConsult,
            method: 'POST',
            dataType: 'json',
            data: {
                data: JSON.stringify({
                    user: user,
                    phone: phone,
                    shops: shops,
                    source_type: source_type,
                    source_level: source_level,
                    source_class: source_class,
                    coupons_flag: coupons_flag,
                })
            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'X-Requested-With': 'XMLHttpRequest',
                'Cookie': 'PFWSSS=' + getGlobalStorage('session_id'),
            }
        })
            .then(res => {
                console.log('购买咨询请求成功', res)
                if (res.data.err_code === 0) {
                    Taro.showToast({ title: '咨询成功', icon: 'success' })
                } else {
                    Taro.showToast({ title: res.data.err_msg, icon: 'none' })

                }
            }).catch(err => {
                console.log('购买咨询请求失败', err)
            })
    }



    // 咨询弹框。取消。确认
    isOpenConsult() {
        this.setState({
            isOpenConsult: true,

        }, () => {
            this.getConsultInfo({})
        })

    }
    consultModalClose() {
        this.setState({ isOpenConsult: false })
    }
    consultModalConfirm() {
        if (!this.state.userName) {
            Taro.showToast({
                title: '请填写姓名',
                icon: 'none',
            })

        } else if (!this.state.userPhone) {
            Taro.showToast({
                title: '请填写电话',
                icon: 'none',
            })

        } else {
            this.setState({ isOpenConsult: false })
            this.buyConsult({})
        }


    }
    handleInputCsultName(e) {
        this.setState({ userName: e.detail.value })
    }
    handleInputCsultPhone(e) {
        this.setState({ userPhone: e.detail.value })
    }
    getDataFromChild(value) {
        console.log('从voucherposter件传回来的值', value)
        this.setState({ isOpenVoucher: value })
    }
    isOpenVoucher() {

        this.setState({
            isOpenVoucher: true,
            userName: getGlobalStorage('user_identity').username,
            userPhone: getGlobalStorage('user_identity').userphone
        }, () => {
            this.getVoucherInfo({})
        })
    }
    componentWillReceiveProps(nextProps) {
        //console.log(this.props, nextProps)
    }
    componentDidMount() {
        this.setState({
            userName: getGlobalStorage('user_identity') ? getGlobalStorage('user_identity').username : '',
            userPhone: getGlobalStorage('user_identity') ? getGlobalStorage('user_identity').userphone : '',
        })
    }
    componentWillUnmount() { }

    componentDidShow() { }

    componentDidHide() { }


    render() {
        const title = this.props.shop.shop_name
        const imgUrl = URL.Base + this.props.shop.goods[0].goods_url
        const price = this.props.shop.goods[0].goods_price
        const goods = this.props.shop.goods
        const ProductName = this.props.shop.goods[0].goods_name
        const address = this.props.shop.shop_address
        const distance = this.props.shop.distance
        const ads = this.props.shop.ads
        const voucherLeft = this.props.shop.left_nums // 优惠券是否为灰色
        const isShowConsultButton = this.props.shop.wx_open === '0' ? false : true // 优惠券是否为灰色
        const slicedGoods = goods !== null ? goods.slice(1) : null
        const goodsElementsArray = goods !== null ? slicedGoods.map((item, index) => {
            return <View className='goods-img-box' key={index}>
                <Image className='goods-img' onClick={this.goToShop.bind(this, this.props.shop)}
                    mode='aspectFit' style='max-height: 100%; max-width: 100%;'
                    src={URL.Base + item.goods_url}
                />
            </View>
        }) : null

        //  优惠券和咨询元素
        const consultModalElement = <AtModal isOpened={this.state.isOpenConsult}>
            <AtModalHeader>咨询</AtModalHeader>
            <AtModalContent>

                <AtNoticebar >
                    <Text >提示:{this.state.consultTip}</Text>
                </AtNoticebar>
                <View className='input-box' >
                    <View className='title' >
                        <Text>联系人：</Text>
                    </View>
                    <View className='value'>
                        <Input name='value'
                            type='text'
                            value={this.state.userName}
                            placeholder='请输入联系人'
                            onInput={this.handleInputCsultName.bind(this)}
                        />
                    </View>


                </View>
                <View className='input-box'>
                    <View className='title'>
                        <Text>联系电话：</Text>
                    </View>
                    <View className='value'>
                        <Input name='value'
                            type='number'
                            maxLength='11'
                            value={this.state.userPhone}
                            placeholder='请输入联系电话'
                            onInput={this.handleInputCsultPhone.bind(this)}
                        />
                    </View>
                </View>
            </AtModalContent>
            <AtModalAction>
                <Button onClick={this.consultModalClose.bind(this)} >取消</Button>
                <Button disabled={!this.state.isCanConsult} className={!this.state.isCanConsult ? 'confirm_button blur' : 'confirm_button'} onClick={this.consultModalConfirm.bind(this)}>确定</Button>
            </AtModalAction>
        </AtModal>

        //            <AtModalAction> <Button onClick={this.consultModalClose.bind(this)} >取消</Button> {this.props.canConsult?<Button style='color:#FF7142'  onClick={this.consultModalConfirm.bind(this)}>确定</Button>:<Text></Text>} </AtModalAction>

        return (
            <View className='shop-list-box' >
                {consultModalElement}
                <VoucherPosterComponent
                    name={this.state.userName}
                    phone={this.state.userPhone}
                    shopId={this.props.shop.shop_id}
                    isCanVoucher={this.state.isCanVoucher}
                    isVoucherPoster={this.state.isOpenVoucher}
                    onPassDataToChild={this.getDataFromChild.bind(this)}
                    voucherLeft={this.props.shop.left_nums}
                    voucherResponseMsg={this.state.voucherResponseMsg}
                    categoryLevel={this.props.categoryLevel}
                    classId={this.props.classId === '-1' ? '' : this.props.classId}
                ></VoucherPosterComponent>
                <View className='header'>

                    <View className='title' style='text-align:left'>
                        <Image src={ads !== 0 ? hornIcon : houseIcon} style='width:12px; height:12px; vertical-align: middle;' />
                        <Text style='margin-left:2px; vertical-align: middle;'>  {title}</Text>
                    </View>

                    <View className='button-container' style='margin-right:5px'>
                        {voucherLeft ? <View className='button' onClick={this.isOpenVoucher.bind(this)} >
                            <Button size='mini' className='button-blue-mini'>
                                优惠券</Button>
                        </View> : <View className='button blur' onClick={this.isOpenVoucher.bind(this)} >
                                <Button size='mini' className='button-blue-mini'>优惠券</Button>
                            </View>}

                        {isShowConsultButton ? <View className='button contult-button' onClick={this.isOpenConsult.bind(this)} >
                            <Button size='mini' className='button-blue-mini'>
                                询价</Button>
                        </View> : null}

                    </View>
                </View>
                <View className='body'>
                    <View className='shop-img' onClick={this.goToShop.bind(this, this.props.shop)}>
                        <Image mode='aspectFit' style=' max-height: 100%; max-width: 100%;' src={imgUrl} />
                    </View>
                    {goods.length !== 1 ? <View className='images'>{goodsElementsArray}</View> : <View className='details'>
                        <View className='details-block'><Text className='details-text'>商品:</Text> {ProductName}</View>
                        <View className='details-block'><Text className='details-text'>价格: </Text><Text>{price}</Text></View>
                    </View>}

                </View>
                <View className='footer'>
                    <View className='address'>
                        <AtIcon value='map-pin' size='15' color='#999'></AtIcon>
                        <Text>{address} </Text> </View>
                    <View className='distance'><Text>{distance}</Text></View>

                </View>
            </View>
        )
    }
}

export default recommondShop
