import Taro, { Component } from '@tarojs/taro'
import { View, Input, Text, Button } from '@tarojs/components'
import { AtIcon } from 'taro-ui'


import './voucherPosterComponent.scss'
import URL from '../../../serviceAPI.config'
import loginExpired from '../../../util/loginExpired'
import { getGlobalStorage } from '../../../util/getSetStoage';



class VoucherPoster extends Component {
  config = {
    navigationBarTitleText: '优惠券活动弹窗'
  }

  constructor() {
    super(...arguments);
    this.state = {
      voucherName: this.props.name,
      voucherPhone: this.props.phone,

      voucherPosterImage: 'background-image:url(' + URL.Base + '/Public/images/store/m_yhq.png);'
    }
  }
  // api 购买咨询 BuyConsult
  buyConsult({
    user = this.state.voucherName,
    phone = this.state.voucherPhone,
    shops = [this.props.shopId],
    source_type = '4',
    source_level = this.props.categoryLevel,
    source_class = this.props.classId,
    coupons_flag = '1' }) {
    Taro.request({
      url: URL.BuyConsult,
      method: 'POST',
      dataType: 'json',
      data: {
        data: JSON.stringify({
          user: user,
          phone: phone,
          shops: shops,
          source_type: source_type,
          source_level: source_level,
          coupons_flag: coupons_flag,
          source_class: source_class
        })
      },
      header: {
        'content-type': 'application/x-www-form-urlencoded',
        'X-Requested-With': 'XMLHttpRequest',
        'Cookie': 'PFWSSS=' + getGlobalStorage('session_id'),
      }
    })
      .then(res => {
        console.log('购买咨询请求成功', res)
        if (res.data.err_code === 0) {
          Taro.showToast({
            title: '咨询成功',
            icon: 'success',
            duration: 1500
          })
          setTimeout(() => {
            this.passDataToParent()
          }, 1500);

        } else if (res.data.err_code === 88888) {
          loginExpired(res)
        } else {
          Taro.showToast({
            title: res.data.err_msg,
            icon: 'none',
            duration: 1500
          })

        }
      }).catch(err => {
        console.log('购买咨询请求失败', err)
      })
  }
  // 确认键
  voucherModalConfirm() {
    if (!this.state.voucherName) {
      Taro.showToast({
        title: '请填写姓名',
        icon: 'none',
      })
    } else if (this.state.voucherPhone.length !== 11) {
      Taro.showToast({
        title: '请填正确的电话号码',
        icon: 'none',
      })
    } else {
      this.buyConsult({})

    }

  }
  //名字输入
  handleNameChange(value) {
    this.setState({ voucherName: value.detail.value })
  }
  //号码输入
  handlePhoneChange(value) {
    this.setState({ voucherPhone: value.detail.value })
  }
  passDataToParent() {
    this.props.onPassDataToChild(false)
  }
  componentWillReceiveProps(nextProps) {

  }
  componentDidMount() {

  }
  componentWillUnmount() { }

  componentDidShow() {

  }

  componentDidHide() { }

  render() {
    return (
      <View className='voucherEventPopUpComponent'>
        {/* <!-- The Modal --> */}
        <View className='modal myModal' style={this.props.isVoucherPoster ? 'display:block' : 'display:none'}>
          <View className='modal-content'   >
            <View className=' absolute container' style={this.state.voucherPosterImage} >
              <View className='close-icon' onClick={this.passDataToParent.bind(this)}>
                <AtIcon value='close-circle' size='30' color='#3F536E'></AtIcon>
              </View>

              <View className='voucher-left'>
                当前优惠券<Text class='left-amount'>{this.props.voucherLeft}</Text>张
            </View>
              <View className='input-name' >
                <View className='title' style='padding:0px'> <Text>联系人：</Text></View>
                <Input class='input-info' type='text' placeholder='请输入联系人' value={this.props.name} onInput={this.handleNameChange.bind(this)} />
              </View>
              <View className='input-number' >
                <View className='title' style='padding:0px'> <Text>联系电话：</Text></View>
                <Input class='input-info' placeholder='请输入联系电话' type='number' maxLength='11' value={this.props.phone} onInput={this.handlePhoneChange.bind(this)} />
              </View>
              <View>
              </View>
              <View className='tips'>
                {this.props.canConsult ? '' : this.props.voucherResponseMsg}
              </View>

              <View className='button' >
                <Button size='default' disabled={!this.props.isCanVoucher} style='border:0px;line-hight:47px;padding:0;' className={!this.props.isCanVoucher ? 'button-orange blur' : 'button-orange'} onClick={this.voucherModalConfirm.bind(this)}>预约领取</Button>
              </View>
              <View className='declare'>

                <Text className='title'>领取须知:</Text>

                <View>1、用户拥有晨丰爱家网平台帐号；</View>
                <View>2、用户关注并绑定定制家居运营平台微信公众号；</View>
                <View>3、用户预约成功后，需要在规定时间内到商家店内领取;</View>
                <View>4、优惠券具体使用规矩，以领取到的优惠券上的规则为准；</View>
                <View>5、购买商品时，可以直接使用优惠券进行现金抵扣；</View>
                <View>6、优惠券兑换现金操作请到指定地点进行兑换申请；</View>
                <View>7、具体兑换规则，到指定兑换点进行查看。</View>

                <View className='address'>兑换点地址:</View>
                <View className='address-a'>福州市鼓楼区铜盘路软件大道89号软件园D区34楼4层福州晨丰科技有限公司</View>

              </View>
            </View>

          </View>
        </View>

      </View>
    )
  }
}

export default VoucherPoster
