
import Taro, { Component } from '@tarojs/taro'
import { View, Text, Image, Button } from '@tarojs/components'
import { AtIcon } from 'taro-ui'

import URL from '../../serviceAPI.config'


import './pictureUploadComponent.scss'
import onClickValueService from '../../util/onClickValueService';
import { getGlobalStorage } from '../../util/getSetStoage';


class PictureUploadComponent extends Component {


    // maxLength={4}
    // isReceiveImageUrl={true}
    // url={URL.UploadDSPorductImage}
    // onGetImageDetails={this.getImageDetails.bind(this)}
    // initialImageURL={this.state.initialImageURL}
    // initialImagesInfo={this.state.initialImagesInfo}
    static defaultProps = {
        url: '',
        maxLength: 100,
        isReceiveImageUrl: true,
        imageURLList: []
    };
    config = {
        navigationBarTitleText: 'pictureUploadComponent'
    }
    constructor() {
        super(...arguments);

        this.state = {
            imageURL: [],
            imageDetails: [],
            onlyOnce: true,// initial props 只setstate一次 
        }
    }
    uploadImage() {
        const that = this
        my.chooseImage({
            count: this.props.maxLength,
            sizeType: ['original', 'compressed'],
            sourceType: ['album', 'camera'],
            success(res) {
                // tempFilePath可以作为img标签的src属性显示图片
                // console.log('res.apFilePaths',res.apFilePaths)
                res.apFilePaths.forEach(item => {
                    that.onChangeImg(item)
                });
            },
            fail(err) {
                Taro.showToast({
                    title: err,
                    icon: 'none'
                })
            }
        })
    }
    // 上传图片apo
    onChangeImg(files) {
        const that = this
        my.uploadFile({
            url: this.props.url,
            filePath: files,
            fileName: 'file',
            fileType: 'image',
            formData: {
                'key': 'michael',
            },
            header: {
                'content-type': 'multipart/form-data; boundary=----WebKitFormBoundaryAWxeadaAVmRVQCiz',
                'Cookie': 'PFWSSS=' + getGlobalStorage('session_id'),
                'X-Requested-With': 'XMLHttpRequest'
            },
            success(response) {
                const data = JSON.parse(response.data)

                if (data.err_code === 0) {
                    console.log('上传成功')
                    const imagePath = URL.Base + data.file_path
                    that.setState({ imageURL: [...that.state.imageURL, { url: imagePath }], imageDetails: [...that.state.imageDetails, data] }, () => {
                        that.props.onGetImageDetails(that.state.imageDetails)
                    })
                    Taro.showToast({
                        title: '上传成功',
                        icon: 'success',
                        duration: 1500
                    })
                } else {
                    Taro.showToast({
                        title: data.err_msg,
                        icon: 'none',
                        duration: 1500
                    })
                }

            },
            fail(err) {
                Taro.showToast({
                    title: err,
                    icon: 'none'
                })
            }
        })


    }

    deleteButton(e) {
        const value = onClickValueService(e)
        this.state.imageURL.splice(value, 1)
        this.state.imageDetails.splice(value, 1)
        this.setState({
            imageURL: this.state.imageURL,
            imageDetails: this.state.imageDetails,
        }, () => {
            this.props.onGetImageDetails(this.state.imageDetails)
        })
        Taro.showToast({
            title: '删除成功',
            icon: 'success',
            duration: 1500
        })
    }

    componentDidMount() {

    }
    // 当然父组件有新的props的 会从新渲染组件
    componentWillReceiveProps(nextProps) {
        // 第一次的props 要给state
        console.log('next props', nextProps)
        if (nextProps.isReceiveImageUrl) {
            if (this.state.onlyOnce) {
                console.log('onlyonce')
                this.setState({
                    imageURL: nextProps.initialImageURL,
                    imageDetails: nextProps.initialImagesInfo,
                    onlyOnce: false
                })

            }
        }

    }
    componentWillUnmount() { }


    componentDidShow() { }

    componentDidHide() { }

    render() {
        console.log('state', this.state)
        const { maxLength } = this.props
        const imageElementArray = this.state.imageURL.map((item, index) => {
            return <View key={index} className='image-wrapper'>
                <View className='delete' onClick={this.deleteButton.bind(this, index)}><AtIcon value='close' size='15' color='#FFFFFF'></AtIcon>
                </View>
                <Image className='goods-img'
                    mode='aspectFit' style='max-height: 100%; max-width: 100%;'
                    src={item.url}
                />
            </View>
        })

        return (

            <View class='pictureUploadComponent' > {this.state.imageURL.length < maxLength ? <Button onClick={this.uploadImage.bind(this)}>上传图片</Button> : null} < View className='image-container' > {imageElementArray}</View></View>
        )
    }
}

export default PictureUploadComponent

