import Taro, { Component } from '@tarojs/taro'
import { View, Text } from '@tarojs/components'
import { AtInput, AtImagePicker, AtTextarea, Button, } from 'taro-ui'

import ShopTypeInteractionComp from '../../component/shopTypeInteractionComp/shopTypeInteractionComp'
import CopyrightComponent from '../../component/copyrightComponent/copyrightComponent'
import PictureUploadComponent from '../../component/pictureUploadComponent/pictureUploadComponent'

import URL from '../../serviceAPI.config'
import './myGoodsEdit.scss'
import loginExpired from '../../util/loginExpired';
import { getGlobalStorage } from '../../util/getSetStoage';
import { showLoading } from '../../util/hideShowLoading';

class MyGoodsEdit extends Component {
    config = {
        navigationBarTitleText: '编辑商品'
    }
    constructor() {
        super(...arguments)
        this.state = {
            shopTypeSelected: { name: '全部', id: '' },
            productName: '',
            productPrice: '',
            productUnit: '',
            productDescript: '',
            pickerImageUrl: [], // 上传的图片
            ImagesInfo: [],// 后台传回来的图片信息
            initialImagesInfo: [],//初始化图片信息
            initialImageURL: [],//初始化图片url
            goodsTypeParam: '',//商品分类参数
            goodId: '',//商品id
            isSaveButton: false,//是否点击了保存按钮
            isSaveAndNewBUtton: false,// 是否点击了保存新增按钮
        }
    }

    //获取商品信息api GetProductInfo
    getGoodsInfo() {
        Taro.request({
            url: URL.GetProductInfo,
            method: 'GET',
            dataType: 'json',
            data: {
                goodsID: this.$router.params.id,
            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'Cookie': 'PFWSSS=' + getGlobalStorage('session_id'),
                'X-Requested-With': 'XMLHttpRequest'
            }
        })
            .then(res => {
                Taro.hideLoading()
               
                if (res.data.err_code === 0) {
                    console.log('商品详情获取成功', res)

                    const imageFile = res.data.goodsFiles.map((item) => {
                        return { url: URL.Base + item.files.file_path }
                    })
                    let shopTypeSelected

                    const shopTypeId = res.data.goods.shop_class_id
                    for (let key in this.state.shopTypeList) {
                        for (let item of this.state.shopTypeList[key].c) {
                            if (item.id === shopTypeId) {
                                shopTypeSelected = { name: item.n, id: item.id }
                            }
                        }
                    }
                    if (getGlobalStorage('shopTypeObject')) {
                        let selectedValue = ''
                        const shopTypeObject = getGlobalStorage('shopTypeObject')
                        console.log('shopTypeObject',shopTypeObject)
                        for (let key in shopTypeObject) {
                            for (let item of shopTypeObject[key].c) {
                                if (item.id === res.data.goods.shop_class_id) {
                                    selectedValue = { name: item.n, id: item.id }
                                }
                            }
                        }
                        this.setState({
                            productName: res.data.goods.goods_name,
                            productPrice: res.data.goods.goods_price,
                            productUnit: res.data.goods.goods_unit,
                            productDescript: res.data.goods.goods_profiles,
                            pickerImageUrl: imageFile,
                            ImagesInfo: res.data.goodsFiles,
                            initialImageURL: imageFile,
                            initialImagesInfo:  res.data.goodsFiles,
                             shopTypeSelected: selectedValue,
                            goodsTypeParam: res.data.goods.class_id,
                            goodId: res.data.goods.goods_id,
                        })

                     }

                } else if (res.data.err_code === 88888) {
                    console.log('88888')
                    loginExpired(res)
                }
                else {
                    Taro.showToast({
                        title: res.data.err_msg,
                        icon: 'none',
                    })
                }

            }
            )
            .catch(error => {
                console.log('商品详情获取失败', error)
            })
    }
    // 发布商品api
    uploadGoods({ goods_name = "test2",
        goods_price = "1.00",
        goods_unit = "1",
        goods_profiles = "test2",
        class_id = "10103",
        shop_class_id = "1930",
        goods_id = '123' }) {
        // 上传图片的参数
        const uploadProductGoodFileParams = []
        if (this.state.ImagesInfo.length) {
            for (let i = 0; i < this.state.ImagesInfo.length; i++) {
                if (i === 0) {
                    uploadProductGoodFileParams.push({
                        file_id: this.state.ImagesInfo[i].file_id,
                        file_type: 1,
                        if_cover: 1,
                        file_sort: 1
                    })
                } else {
                    uploadProductGoodFileParams.push({
                        file_id: this.state.ImagesInfo[i].file_id,
                        file_type: 1,
                        if_cover: 0,
                        file_sort: i + 1

                    })
                }
            }
        } else {
            alert('图片为空')
        }

        Taro.request({
            url: URL.UploadProduct,
            method: 'POST',
            dataType: 'json',
            data: {
                deployType: 2,
                action: 2,
                goods: JSON.stringify({
                    goods_name: goods_name,
                    goods_price: goods_price,
                    goods_unit: goods_unit,
                    goods_profiles: goods_profiles,
                    class_id: class_id,
                    shop_class_id: shop_class_id,
                    goods_id: goods_id,
                }),
                goodsFiles: JSON.stringify(uploadProductGoodFileParams)
            },
            header: {
                'content-type': 'application/x-www-form-urlencoded',
                'Cookie': 'PFWSSS=' + getGlobalStorage('session_id'),
                'X-Requested-With': 'XMLHttpRequest'
            }
        })
            .then(res => {
                Taro.hideLoading()

                if (res.data.err_code === 0) {
                    Taro.showToast({
                        title: '保存成功',
                        icon: 'success',
                        duration: 1500
                    }).then(() => {
                        setTimeout(() => {
                            if (this.state.isSaveButton) {
                                //  Taro.navigateBack({

                                //   delta:1
                                // url: '/pages/myGoodsList/myGoodsEdit?id=' + this.$router.params.id
                                // })
                                Taro.redirectTo({
                                    url: '/pages/myGoodList/myGoodList'
                                })
                            } else if (this.state.isSaveAndNewBUtton) {
                                Taro.switchTab({
                                    url: '/pages/goodsPublish/goodsPublish'
                                })
                            }
                        }, 1000);
                    })
                } else if (res.data.err_code === 88888) {
                    loginExpired(res)
                } else {
                    Taro.hideLoading()
                    Taro.showToast({
                        title: res.data.err_msg,
                        icon: 'none',
                        duration: 1500
                    })
                }
            }
            )

    }
    productNameChange(event) {
        this.setState({
            productName: event
        })
    }
    productPriceChange(event) {
        this.setState({
            productPrice: event
        })
    }
    productUnitChange(event) {
        this.setState({
            productUnit: event
        })
    }
    productDescriptChange(event) {
        this.setState({
            productDescript: event.target.value
        })
    }
    // 上传图片
    onChangeImg(files, operationType, index) {
        const that = this
        if (operationType === 'add') {
            Taro.uploadFile({
                url: URL.UploadGoodsPorductImage,
                filePath: files[files.length - 1].url,
                name: 'file',
                formData: {
                    user: 'test'
                },
                header: {
                    'content-type': 'multipart/form-data',
                    'Cookie': 'PFWSSS=' + getGlobalStorage('session_id'),
                    'X-Requested-With': 'XMLHttpRequest'
                },
                success(response) {
                    const data = JSON.parse(response.data)
                    if (data.err_code === 0) {
                        console.log('imagedata', data)
                        const imagePath = URL.Base + data.file_path
                        const newPickerImageUrl = that.state.pickerImageUrl.concat({ url: imagePath })
                        const newImageInfo = that.state.ImagesInfo.concat(data)
                        console.log('新添加后的图片列表', newImageInfo)

                        that.setState({
                            pickerImageUrl: newPickerImageUrl,
                            ImagesInfo: newImageInfo
                        }, () => {
                            Taro.showToast({
                                title: '上传成功',
                                icon: 'success',
                                duration: 2000
                            })
                        })

                    } else {
                        Taro.showToast({
                            title: data.err_msg,
                            icon: 'none',
                            duration: 1500
                        })
                    }

                }
            })
        }
        if (operationType === 'remove') {
            this.state.pickerImageUrl.splice(index, 1);// 删除图片param
            this.state.ImagesInfo.splice(index, 1) // 删除显示的图片

            this.setState({
                pickerImageUrl: this.state.pickerImageUrl,
                ImagesInfo: this.state.ImagesInfo
            });

            Taro.showToast({
                title: '删除成功',
                icon: 'success',
                duration: 2000
            })

        }
    }
      // 从图片子组件获取信息
  getImageDetails(value) {
    this.setState({
      ImagesInfo: value
    })
  }
    shopCategoryChanged(e) {
        this.setState({
            shopCategoryCheckedPicker: this.state.shopCategoryList[e.detail.value]
        }, () => {
            console.log(this.state.shopCategoryCheckedPicker)
        })
    }
    // 保存按钮
    saveButtonHandler() {
        if (this.state.productName && this.state.productPrice && this.state.productUnit && this.state.ImagesInfo.length && this.state.shopTypeSelected.id) {
            showLoading({ title: '保存中' })
            this.setState({ isSaveButton: true }, () => {
                this.uploadGoods({
                    goods_name: this.state.productName,
                    goods_price: this.state.productPrice,
                    goods_unit: this.state.productUnit,
                    goods_profiles: this.state.productDescript,
                    shop_class_id: this.state.shopTypeSelected.id,
                    class_id: this.state.goodsTypeParam,
                    goods_id: this.state.goodId,
                })

            })

        } else {
            Taro.showToast({
                title: '请填写完表格',
                icon: 'none',
                duration: 2000
            })

        }
    }
    // 保存并新增按钮
    saveAndNewButton() {
        if (this.state.productName && this.state.productPrice && this.state.productUnit && this.state.ImagesInfo.length && this.state.shopTypeSelected.id) {
            showLoading({ title: '保存中' })
            this.setState({ isSaveAndNewBUtton: true }, () => {
                this.uploadGoods({
                    goods_name: this.state.productName,
                    goods_price: this.state.productPrice,
                    goods_unit: this.state.productUnit,
                    goods_profiles: this.state.productDescript,
                    shop_class_id: this.state.shopTypeSelected.id,
                    class_id: this.state.goodsTypeParam,
                    goods_id: this.state.goodId,
                })

            })


        } else {
            Taro.showToast({
                title: '请填写完表格',
                icon: 'none',
                duration: 2000
            })

        }
    }

    goToGoodsDetailPage() {
        Taro.navigateTo({
            url: '/pages/goods/goods?id=' + this.$router.params.id
        })
    }
    goToMyGoodListPage() {
        Taro.redirectTo({
            url: '/pages/myGoodList/myGoodList'
        })
    }

    getDataFromShopChild(value) {
        console.log('从子组件店铺分类传回来的值', value)
        this.setState({ shopTypeSelected: value })
    }


    componentDidMount() {
        showLoading({
            title: '加载中'
        })
        this.getGoodsInfo()

    }

    componentWillReceiveProps(nextProps) {
        // console.log(this.props, nextProps)
    }
    componentWillUnmount() { }

    componentDidShow() { }

    componentDidHide() { }



    render() {
        return (
            <View className='goods-publish'>
                <View className='goods-category'>
                    <View className='input-box'>
                        <Text className='require'>*</Text>
                        <AtInput
                            name='productName'
                            title='商品名称：'
                            type='text'
                            value={this.state.productName}
                            border={false}
                            onChange={this.productNameChange.bind(this)}


                        />
                    </View>
                    <View className='input-box'>
                        <Text className='require'>*</Text>
                        <AtInput
                            name='productPrice'
                            title='商品价格：'
                            type='number'
                            placeholder='￥'
                            value={this.state.productPrice}
                            border={false}
                            onChange={this.productPriceChange.bind(this)}
                        />
                    </View>
                    <View className='input-box'>
                        <Text className='require'>*</Text>
                        <AtInput
                            name='productUnit'
                            title='商品单位：'
                            type='number'
                            value={this.state.productUnit}
                            border={false}
                            onChange={this.productUnitChange.bind(this)}
                        />
                    </View>
                    {/* 图片上传 */}
                    <View className='img-box'>
                        <View className='title-box'>
                            <Text className='require'>*</Text>
                            <Text className='title'>上传图片:</Text>
                        </View>
                        <PictureUploadComponent
            maxLength={20}
            isReceiveImageUrl={true}
            initialImageURL={this.state.initialImageURL}
            initialImagesInfo={this.state.initialImagesInfo}
            url={ URL.UploadGoodsPorductImage}
            onGetImageDetails={this.getImageDetails.bind(this)}
          />
                        {/* <View className='img-container'>
                            <AtImagePicker
                                multiple
                                files={this.state.pickerImageUrl}
                                onChange={this.onChangeImg.bind(this)}
                                onFail={this.onFail.bind(this)}
                                onImageClick={this.onImageClick.bind(this)}
                            />
                        </View> */}
                    </View>
                    {/* 店铺分类 */}
                    <ShopTypeInteractionComp url={URL.GetShopCategoryList}
                        shopId={getGlobalStorage('shopInfo')?getGlobalStorage('shopInfo').shop_id:''}
                        selectedValue={this.state.shopTypeSelected}
                        onPassDataToChild={this.getDataFromShopChild.bind(this)}

                    ></ShopTypeInteractionComp>
                    {/* 店铺分类结束  */}

                    <View className='description-box'>
                        <View className='title-box'>
                            <Text className='require'></Text>
                            <Text className='title'>商品简介:</Text>
                        </View>

                        <AtTextarea
                            value={this.state.productDescript}
                            onChange={this.productDescriptChange.bind(this)}
                            maxlength='140'
                            placeholder='你的产品简介'
                        />
                    </View>
                    <View className='button-box' >
                        <View className='button' >
                            <Button size='mini' className='button-orange' onClick={this.saveButtonHandler.bind(this)}>保存</Button>
                        </View>
                        {/* <View className='button'>
                        <Button  className='button-a' size='mini' >发布并新增</Button>
                    </View> */}
                        {/* <View className='button' onClick={this.saveAndNewButton.bind(this)}>
                            <Button className='button-green' size='mini'>保存并新增</Button>
                        </View> */}
                        <View className='button' onClick={this.goToGoodsDetailPage.bind(this)}>
                            <Button className='button-green' size='mini'>商品详情</Button>
                        </View>
                        <View className='button' onClick={this.goToMyGoodListPage.bind(this)}>
                            <Button className='button-green' size='mini'>商品列表</Button>
                        </View>
                    </View>
                </View>



                <CopyrightComponent></CopyrightComponent>

            </View>
        )
    }
}

export default MyGoodsEdit
